@@ -26,17 +26,16 @@ sub new {
 	my @packages = @{$dh{DOPACKAGES}};
 	$this->{package} = shift @packages;
 	$this->{doc_package} = (grep /-doc$/, @packages)[0];
-	my $classconf = '/etc/maven2/m2-debian.conf';
-	if (!$this->{doc_package}) {
-		$classconf = '/etc/maven2/m2-debian-nodocs.conf';
-	}
+	my $classconf = '/etc/maven/m2-debian.conf';
 
-	my @classpath = ('/usr/share/maven2/boot/classworlds.jar');
+	my @classpath = ('/usr/share/maven/boot/plexus-classworlds-2.x.jar');
 	if (-e "$java_home/lib/tools.jar") {
 		push(@classpath, "$java_home/lib/tools.jar");
 	}
 
 	my @jvmopts = ('-noverify', '-cp', join(':',@classpath),
+		"-Dmaven.home=/usr/share/maven",
+		"-Dmaven.multiModuleProjectDirectory=$this->{cwd}",
 		"-Dclassworlds.conf=$classconf");
 	if (-e "$this->{cwd}/debian/maven.properties") {
 		push (@jvmopts, "-Dproperties.file.manual=$this->{cwd}/debian/maven.properties");
@@ -44,8 +43,8 @@ sub new {
 
 	@{$this->{maven_cmd}} = ($java_home . '/bin/java',
 		@jvmopts,
-		"org.codehaus.classworlds.Launcher",
-		"-s/etc/maven2/settings-debian.xml",
+		"org.codehaus.plexus.classworlds.launcher.Launcher",
+		"-s/etc/maven/settings-debian.xml",
 		"-Ddebian.dir=$this->{cwd}/debian",
 		"-Dmaven.repo.local=$this->{cwd}/debian/maven-repo");
 	return $this;
@@ -54,9 +53,6 @@ sub new {
 sub configure {
 	my $this=shift;
 	my @patch_args;
-	if (! $this->{doc_package}) {
-		push(@patch_args, "--build-no-docs");
-	}
 
 	doit("/usr/share/maven-debian-helper/copy-repo.sh", "$this->{cwd}/debian");
 	$this->doit_in_sourcedir("mh_patchpoms", "-p$this->{package}",
@@ -75,7 +71,7 @@ sub build {
 		}
 	}
 
-	push(@_, "-DskipTests");
+	push(@_, "-DskipTests", "-Dnotimestamp=true", "-Dlocale=en_US");
 
 	$this->doit_in_builddir(@{$this->{maven_cmd}}, @_);
 }
@@ -131,19 +127,10 @@ sub clean {
 		$this->doit_in_builddir_noerror(@{$this->{maven_cmd}}, "clean");
 		doit("rm", "-r", "$this->{cwd}/debian/maven-repo");
 	}
+	$this->doit_in_builddir('for dir in $(find . -name target -type d); do if [ -f $(echo $dir | sed -e s/target$/pom.xml/) ]; then rm -Rf $dir; fi done');
 	$this->doit_in_sourcedir("mh_unpatchpoms", "-p$this->{package}");
 	doit("rm", "-f", "debian/stamp-poms-patched");
 	doit("mh_clean");
 }
 
-# FIXME: no standard check target to use here?
-#sub test {
-#	my $this=shift;
-#	$this->doit_in_builddir(@{$this->{maven_cmd}},
-#		"-Ddebian.dir=$this->{cwd}/debian",
-#		"-Ddebian.package=$this->{package}",
-#		"-Dinstall.to.usj=true",
-#		??);
-#}
-
 1
